@@ -4,7 +4,7 @@ use base qw(Number::Tolerant::Type);
 use strict;
 use warnings;
 
-our $VERSION = '1.52';
+our $VERSION = '1.540';
 
 my $number = $Number::Tolerant::Type::number;
 my $X = $Number::Tolerant::Type::X;
@@ -13,11 +13,12 @@ sub construct { shift; $_[0] }
 
 sub parse { shift;
   return $_[0] if ($_[0] =~ m!\A($number)\z!);
+  return;
 }
 
 sub valid_args { shift;
   return $_[0] if @_==1 and defined $_[0] and $_[0] =~ m!\A($number)\z!;
-  return
+  return;
 }
 
 1;
