@@ -4,7 +4,7 @@ use base qw(Number::Tolerant::Type);
 use strict;
 use warnings;
 
-our $VERSION = '1.52';
+our $VERSION = '1.540';
 
 my $number = $Number::Tolerant::Type::number;
 my $X = $Number::Tolerant::Type::X;
@@ -25,7 +25,8 @@ sub parse { shift;
   return Number::Tolerant::tolerance("$2", 'to', "$1")
     if ($_[0] =~ m!\A($number)\s*>=$X>=\s*($number)\z!);
   return Number::Tolerant::tolerance("$1", 'to', "$2")
-    if ($_[0] =~ m!\A($number) to ($number)\z!)
+    if ($_[0] =~ m!\A($number)\s+to\s+($number)\z!);
+  return;
 }
 
 sub valid_args { shift;
